@@ -1,13 +1,14 @@
 import copy
 import os
 import subprocess
-from typing import Mapping, Optional
+from collections.abc import Mapping
+from typing import Optional
 
 import click
 import dagster._check as check
 import nbformat
-from dagster._seven.json import loads
 from dagster._utils import mkdir_p, safe_isfile
+from dagster_shared.seven.json import loads
 from papermill.iorw import load_notebook_node, write_ipynb
 
 
@@ -110,11 +111,9 @@ def execute_create_notebook(notebook: str, force_overwrite: bool, kernel: str):
 
     if not force_overwrite and safe_isfile(notebook_path):
         click.confirm(
-            (
-                "Warning, {notebook_path} already exists and continuing "
-                "will overwrite the existing notebook. "
-                "Are you sure you want to continue?"
-            ).format(notebook_path=notebook_path),
+            f"Warning, {notebook_path} already exists and continuing "
+            "will overwrite the existing notebook. "
+            "Are you sure you want to continue?",
             abort=True,
         )
 
