@@ -4,7 +4,8 @@ import pickle
 import sys
 import tempfile
 import uuid
-from typing import Any, Callable, Iterable, Mapping, Optional, Sequence, Set, Union, cast
+from collections.abc import Callable, Iterable, Mapping, Sequence
+from typing import Any, Optional, Union, cast
 
 import nbformat
 import papermill
@@ -14,31 +15,35 @@ from dagster import (
     Out,
     Output,
     _check as check,
-    _seven,
 )
+from dagster._annotations import beta
+from dagster._config.pythonic_config import Config, infer_schema_from_config_class
+from dagster._config.pythonic_config.type_check_utils import safe_is_subclass
 from dagster._core.definitions.events import AssetMaterialization, Failure, RetryRequested
 from dagster._core.definitions.metadata import MetadataValue
-from dagster._core.definitions.reconstruct import ReconstructablePipeline
-from dagster._core.definitions.utils import validate_tags
+from dagster._core.definitions.reconstruct import ReconstructableJob
 from dagster._core.execution.context.compute import OpExecutionContext
 from dagster._core.execution.context.input import build_input_context
 from dagster._core.execution.context.system import StepExecutionContext
 from dagster._core.execution.plan.outputs import StepOutputHandle
+from dagster._core.storage.tags import COMPUTE_KIND_TAG
 from dagster._serdes import pack_value
-from dagster._seven import get_system_temp_directory
 from dagster._utils import mkdir_p, safe_tempfile_path
 from dagster._utils.error import serializable_error_info_from_exc_info
+from dagster._utils.tags import normalize_tags
+from dagster_shared import seven
+from dagster_shared.seven import get_system_temp_directory
 from papermill.engines import papermill_engines
 from papermill.iorw import load_notebook_node, write_ipynb
 
-from .compat import ExecutionError
-from .engine import DagstermillEngine
-from .errors import DagstermillError
-from .translator import DagsterTranslator
+from dagstermill.compat import ExecutionError
+from dagstermill.engine import DagstermillEngine
+from dagstermill.errors import DagstermillError
+from dagstermill.translator import DagsterTranslator
 
 
 def _clean_path_for_windows(notebook_path: str) -> str:
-    """In windows, the notebook cant render in dagit unless the C: prefix is removed.
+    """In windows, the notebook can't render in the Dagster UI unless the C: prefix is removed.
     os.path.splitdrive will split the path into (drive, tail), so just return the tail.
     """
     return os.path.splitdrive(notebook_path)[1]
@@ -58,6 +63,7 @@ def _find_first_tagged_cell_index(nb, tag):
 # This is based on papermill.parameterize.parameterize_notebook
 # Typically, papermill injects the injected-parameters cell *below* the parameters cell
 # but we want to *replace* the parameters cell, which is what this function does.
+@beta
 def replace_parameters(context, nb, parameters):
     """Assigned parameters into the appropriate place in the input notebook.
 
@@ -99,11 +105,12 @@ def replace_parameters(context, nb, parameters):
         after = nb.cells
 
     nb.cells = before + [newcell] + after
-    nb.metadata.papermill["parameters"] = _seven.json.dumps(parameters)
+    nb.metadata.papermill["parameters"] = seven.json.dumps(parameters)
 
     return nb
 
 
+@beta
 def get_papermill_parameters(
     step_context: StepExecutionContext,
     inputs: Mapping[str, object],
@@ -121,7 +128,7 @@ def get_papermill_parameters(
     marshal_dir = os.path.normpath(os.path.join(temp_dir, "dagstermill", str(run_id), "marshal"))
     mkdir_p(marshal_dir)
 
-    if not isinstance(step_context.pipeline, ReconstructablePipeline):
+    if not isinstance(step_context.job, ReconstructableJob):
         if compute_descriptor == "asset":
             raise DagstermillError(
                 "Can't execute a dagstermill asset that is not reconstructable. "
@@ -133,7 +140,7 @@ def get_papermill_parameters(
                 "Use the reconstructable() function if executing from python"
             )
 
-    dm_executable_dict = step_context.pipeline.to_dict()
+    dm_executable_dict = step_context.job.to_dict()
 
     dm_context_dict = {
         "output_log_path": output_log_path,
@@ -157,6 +164,7 @@ def get_papermill_parameters(
     return parameters
 
 
+@beta
 def execute_notebook(
     step_context: StepExecutionContext,
     name: str,
@@ -197,9 +205,7 @@ def execute_notebook(
 
         except Exception as ex:
             step_context.log.warn(
-                "Error when attempting to materialize executed notebook: {exc}".format(
-                    exc=str(serializable_error_info_from_exc_info(sys.exc_info()))
-                )
+                f"Error when attempting to materialize executed notebook: {serializable_error_info_from_exc_info(sys.exc_info())!s}"
             )
 
             if isinstance(ex, ExecutionError):
@@ -235,7 +241,7 @@ def _handle_events_from_notebook(
 
     output_nb = scrapbook.read_notebook(executed_notebook_path)
 
-    for output_name, _ in step_context.op_def.output_dict.items():
+    for output_name in step_context.op_def.output_dict.keys():
         data_dict = output_nb.scraps.data_dict
         if output_name in data_dict:
             # read outputs that were passed out of process via io manager from `yield_result`
@@ -324,7 +330,7 @@ def _make_dagstermill_compute_fn(
                     op_context.log.warning(
                         "Error when attempting to materialize executed notebook using file"
                         " manager:"
-                        f" {str(serializable_error_info_from_exc_info(sys.exc_info()))}\nNow"
+                        f" {serializable_error_info_from_exc_info(sys.exc_info())}\nNow"
                         " falling back to local: notebook execution was temporarily materialized"
                         f" at {executed_notebook_path}\nIf you have supplied a file manager and"
                         " expect to use it for materializing the notebook, please include"
@@ -340,13 +346,14 @@ def _make_dagstermill_compute_fn(
     return _t_fn
 
 
+@beta
 def define_dagstermill_op(
     name: str,
     notebook_path: str,
     ins: Optional[Mapping[str, In]] = None,
     outs: Optional[Mapping[str, Out]] = None,
     config_schema: Optional[Union[Any, Mapping[str, Any]]] = None,
-    required_resource_keys: Optional[Set[str]] = None,
+    required_resource_keys: Optional[set[str]] = None,
     output_notebook_name: Optional[str] = None,
     asset_key_prefix: Optional[Union[Sequence[str], str]] = None,
     description: Optional[str] = None,
@@ -401,7 +408,7 @@ def define_dagstermill_op(
         required_resource_keys.add(io_mgr_key)
         outs = {
             **outs,
-            cast(str, output_notebook_name): Out(io_manager_key=io_mgr_key),
+            cast("str", output_notebook_name): Out(io_manager_key=io_mgr_key),
         }
 
     if isinstance(asset_key_prefix, str):
@@ -412,23 +419,25 @@ def define_dagstermill_op(
     default_description = f"This op is backed by the notebook at {notebook_path}"
     description = check.opt_str_param(description, "description", default=default_description)
 
-    user_tags = validate_tags(tags)
+    user_tags = normalize_tags(tags)
     if tags is not None:
         check.invariant(
             "notebook_path" not in tags,
-            (
-                "user-defined op tags contains the `notebook_path` key, but the `notebook_path` key"
-                " is reserved for use by Dagster"
-            ),
+            "user-defined op tags contains the `notebook_path` key, but the `notebook_path` key"
+            " is reserved for use by Dagster",
         )
         check.invariant(
-            "kind" not in tags,
-            (
-                "user-defined op tags contains the `kind` key, but the `kind` key is reserved for"
-                " use by Dagster"
-            ),
+            COMPUTE_KIND_TAG not in tags,
+            "user-defined op tags contains the `kind` key, but the `kind` key is reserved for"
+            " use by Dagster",
         )
-    default_tags = {"notebook_path": _clean_path_for_windows(notebook_path), "kind": "ipynb"}
+    default_tags = {
+        "notebook_path": _clean_path_for_windows(notebook_path),
+        COMPUTE_KIND_TAG: "ipynb",
+    }
+
+    if safe_is_subclass(config_schema, Config):
+        config_schema = infer_schema_from_config_class(cast("type[Config]", config_schema))
 
     return OpDefinition(
         name=name,
