@@ -1,15 +1,23 @@
 import os
+from collections.abc import Sequence
 from pathlib import Path
-from typing import Any, Optional, Sequence
+from typing import Any, Optional
 
 import dagster._check as check
-from dagster import AssetKey, AssetMaterialization
-from dagster._config import Field
+from dagster import (
+    AssetKey,
+    AssetMaterialization,
+    ConfigurableIOManagerFactory,
+    InitResourceContext,
+    IOManager,
+)
+from dagster._annotations import beta
 from dagster._core.definitions.metadata import MetadataValue
 from dagster._core.execution.context.input import InputContext
 from dagster._core.execution.context.output import OutputContext
-from dagster._core.storage.io_manager import IOManager, io_manager
+from dagster._core.storage.io_manager import dagster_maintained_io_manager, io_manager
 from dagster._utils import mkdir_p
+from pydantic import Field
 
 from dagstermill.factory import _clean_path_for_windows
 
@@ -26,10 +34,8 @@ class OutputNotebookIOManager(IOManager):
 
 
 class LocalOutputNotebookIOManager(OutputNotebookIOManager):
-    """Built-in IO Manager for handling output notebook."""
-
     def __init__(self, base_dir: str, asset_key_prefix: Optional[Sequence[str]] = None):
-        super(LocalOutputNotebookIOManager, self).__init__(asset_key_prefix=asset_key_prefix)
+        super().__init__(asset_key_prefix=asset_key_prefix)
         self.base_dir = base_dir
         self.write_mode = "wb"
         self.read_mode = "rb"
@@ -70,7 +76,7 @@ class LocalOutputNotebookIOManager(OutputNotebookIOManager):
                 )
             )
 
-    def load_input(self, context) -> bytes:
+    def load_input(self, context: InputContext) -> bytes:
         check.inst_param(context, "context", InputContext)
         # pass output notebook to downstream ops as File Object
         output_context = check.not_none(context.upstream_output)
@@ -78,17 +84,39 @@ class LocalOutputNotebookIOManager(OutputNotebookIOManager):
             return file_obj.read()
 
 
-@io_manager(
-    config_schema={
-        "asset_key_prefix": Field(str, is_required=False),
-        "base_dir": Field(str, is_required=False),
-    },
-)
-def local_output_notebook_io_manager(init_context):
-    """Built-in IO Manager that handles output notebooks."""
-    return LocalOutputNotebookIOManager(
-        base_dir=init_context.resource_config.get(
-            "base_dir", init_context.instance.storage_directory()
+@beta
+class ConfigurableLocalOutputNotebookIOManager(ConfigurableIOManagerFactory):
+    """Built-in IO Manager for handling output notebook."""
+
+    base_dir: Optional[str] = Field(
+        default=None,
+        description=(
+            "Base directory to use for output notebooks. Defaults to the Dagster instance storage"
+            " directory if not provided."
         ),
-        asset_key_prefix=init_context.resource_config.get("asset_key_prefix", []),
     )
+    asset_key_prefix: list[str] = Field(
+        default=[],
+        description=(
+            "Asset key prefix to apply to assets materialized for output notebooks. Defaults to no"
+            " prefix."
+        ),
+    )
+
+    @classmethod
+    def _is_dagster_maintained(cls) -> bool:
+        return True
+
+    def create_io_manager(self, context: InitResourceContext) -> "LocalOutputNotebookIOManager":
+        return LocalOutputNotebookIOManager(
+            base_dir=self.base_dir or check.not_none(context.instance).storage_directory(),
+            asset_key_prefix=self.asset_key_prefix,
+        )
+
+
+@beta
+@dagster_maintained_io_manager
+@io_manager(config_schema=ConfigurableLocalOutputNotebookIOManager.to_config_schema())
+def local_output_notebook_io_manager(init_context) -> LocalOutputNotebookIOManager:
+    """Built-in IO Manager that handles output notebooks."""
+    return ConfigurableLocalOutputNotebookIOManager.from_resource_context(init_context)
