@@ -1,7 +1,9 @@
 import os
 import pickle
 import uuid
-from typing import AbstractSet, Any, Mapping, Optional, cast
+from asyncio import AbstractEventLoop
+from collections.abc import Mapping
+from typing import TYPE_CHECKING, AbstractSet, Any, Optional, cast  # noqa: UP035
 
 from dagster import (
     AssetMaterialization,
@@ -14,19 +16,20 @@ from dagster import (
     TypeCheck,
     _check as check,
 )
+from dagster._annotations import beta
 from dagster._core.definitions.dependency import NodeHandle
 from dagster._core.definitions.events import RetryRequested
-from dagster._core.definitions.node_definition import NodeDefinition
+from dagster._core.definitions.graph_definition import GraphDefinition
+from dagster._core.definitions.job_base import InMemoryJob
+from dagster._core.definitions.job_definition import JobDefinition
 from dagster._core.definitions.op_definition import OpDefinition
-from dagster._core.definitions.pipeline_base import InMemoryPipeline
-from dagster._core.definitions.reconstruct import ReconstructablePipeline
+from dagster._core.definitions.reconstruct import ReconstructableJob
 from dagster._core.definitions.resource_definition import ScopedResourcesBuilder
-from dagster._core.errors import DagsterInvariantViolationError
 from dagster._core.events import DagsterEvent
-from dagster._core.execution.api import scoped_pipeline_context
+from dagster._core.execution.api import create_execution_plan, scoped_job_context
 from dagster._core.execution.plan.outputs import StepOutputHandle
 from dagster._core.execution.plan.plan import ExecutionPlan
-from dagster._core.execution.plan.step import ExecutionStep
+from dagster._core.execution.plan.state import KnownExecutionState
 from dagster._core.execution.resources_init import (
     get_required_resource_keys_to_init,
     resource_initialization_event_generator,
@@ -34,18 +37,20 @@ from dagster._core.execution.resources_init import (
 from dagster._core.instance import DagsterInstance
 from dagster._core.instance.ref import InstanceRef
 from dagster._core.log_manager import DagsterLogManager
-from dagster._core.storage.pipeline_run import DagsterRun, DagsterRunStatus
+from dagster._core.storage.dagster_run import DagsterRun, DagsterRunStatus
 from dagster._core.system_config.objects import ResolvedRunConfig, ResourceConfig
 from dagster._core.utils import make_new_run_id
-from dagster._legacy import ModeDefinition, PipelineDefinition
 from dagster._loggers import colored_console_logger
 from dagster._serdes import unpack_value
 from dagster._utils import EventGenerationManager
-from dagster._utils.backcompat import deprecation_warning
 
-from .context import DagstermillExecutionContext, DagstermillRuntimeExecutionContext
-from .errors import DagstermillError
-from .serialize import PICKLE_PROTOCOL
+from dagstermill.context import DagstermillExecutionContext, DagstermillRuntimeExecutionContext
+from dagstermill.errors import DagstermillError
+from dagstermill.serialize import PICKLE_PROTOCOL
+
+if TYPE_CHECKING:
+    from dagster._core.definitions.node_definition import NodeDefinition
+    from dagster._core.execution.plan.step import ExecutionStep
 
 
 class DagstermillResourceEventGenerationManager(EventGenerationManager):
@@ -58,19 +63,15 @@ class DagstermillResourceEventGenerationManager(EventGenerationManager):
         return iter(())
 
     def teardown(self):
-        return [
-            teardown_event
-            for teardown_event in super(
-                DagstermillResourceEventGenerationManager, self
-            ).generate_teardown_events()
-        ]
+        return [teardown_event for teardown_event in super().generate_teardown_events()]
 
 
+@beta
 class Manager:
     def __init__(self):
-        self.pipeline = None
+        self.job = None
         self.op_def: Optional[NodeDefinition] = None
-        self.in_pipeline: bool = False
+        self.in_job: bool = False
         self.marshal_dir: Optional[str] = None
         self.context = None
         self.resource_manager = None
@@ -85,6 +86,7 @@ class Manager:
         resource_keys_to_init: Optional[AbstractSet[str]],
         instance: Optional[DagsterInstance],
         emit_persistent_events: Optional[bool],
+        event_loop: Optional[AbstractEventLoop],
     ):
         """Drop-in replacement for
         `dagster._core.execution.resources_init.resource_initialization_manager`.  It uses a
@@ -99,16 +101,17 @@ class Manager:
             resource_keys_to_init=resource_keys_to_init,
             instance=instance,
             emit_persistent_events=emit_persistent_events,
+            event_loop=event_loop,
         )
         self.resource_manager = DagstermillResourceEventGenerationManager(
             generator, ScopedResourcesBuilder
         )
         return self.resource_manager
 
-    def reconstitute_pipeline_context(
+    def reconstitute_job_context(
         self,
         executable_dict: Mapping[str, Any],
-        pipeline_run_dict: Mapping[str, Any],
+        job_run_dict: Mapping[str, Any],
         node_handle_kwargs: Mapping[str, Any],
         instance_ref_dict: Mapping[str, Any],
         step_key: str,
@@ -118,26 +121,26 @@ class Manager:
     ):
         """Reconstitutes a context for dagstermill-managed execution.
 
-        You'll see this function called to reconstruct a pipeline context within the ``injected
+        You'll see this function called to reconstruct a job context within the ``injected
         parameters`` cell of a dagstermill output notebook. Users should not call this function
         interactively except when debugging output notebooks.
 
         Use :func:`dagstermill.get_context` in the ``parameters`` cell of your notebook to define a
         context for interactive exploration and development. This call will be replaced by one to
-        :func:`dagstermill.reconstitute_pipeline_context` when the notebook is executed by
+        :func:`dagstermill.reconstitute_job_context` when the notebook is executed by
         dagstermill.
         """
         check.opt_str_param(output_log_path, "output_log_path")
         check.opt_str_param(marshal_dir, "marshal_dir")
         run_config = check.opt_mapping_param(run_config, "run_config", key_type=str)
-        check.mapping_param(pipeline_run_dict, "pipeline_run_dict")
+        check.mapping_param(job_run_dict, "job_run_dict")
         check.mapping_param(executable_dict, "executable_dict")
         check.mapping_param(node_handle_kwargs, "node_handle_kwargs")
         check.mapping_param(instance_ref_dict, "instance_ref_dict")
         check.str_param(step_key, "step_key")
 
-        pipeline = ReconstructablePipeline.from_dict(executable_dict)
-        pipeline_def = pipeline.get_definition()
+        job = ReconstructableJob.from_dict(executable_dict)
+        job_def = job.get_definition()
 
         try:
             instance_ref = unpack_value(instance_ref_dict, InstanceRef)
@@ -147,52 +150,56 @@ class Manager:
                 "Error when attempting to resolve DagsterInstance from serialized InstanceRef"
             ) from err
 
-        dagster_run = unpack_value(pipeline_run_dict, DagsterRun)
+        dagster_run = unpack_value(job_run_dict, DagsterRun)
 
         node_handle = NodeHandle.from_dict(node_handle_kwargs)
-        op = pipeline_def.get_node(node_handle)
+        op = job_def.get_node(node_handle)
         op_def = op.definition
 
         self.marshal_dir = marshal_dir
-        self.in_pipeline = True
+        self.in_job = True
         self.op_def = op_def
-        self.pipeline = pipeline
+        self.job = job
 
-        resolved_run_config = ResolvedRunConfig.build(
-            pipeline_def, run_config, mode=dagster_run.mode
-        )
+        ResolvedRunConfig.build(job_def, run_config)
 
-        execution_plan = ExecutionPlan.build(
-            self.pipeline,
-            resolved_run_config,
+        execution_plan = create_execution_plan(
+            self.job,
+            run_config,
             step_keys_to_execute=dagster_run.step_keys_to_execute,
         )
 
-        with scoped_pipeline_context(
+        with scoped_job_context(
             execution_plan,
-            pipeline,
+            job,
             run_config,
             dagster_run,
             instance,
             scoped_resources_builder_cm=self._setup_resources,
             # Set this flag even though we're not in test for clearer error reporting
             raise_on_error=True,
-        ) as pipeline_context:
+        ) as job_context:
+            known_state = None
+            if dagster_run.parent_run_id:
+                known_state = KnownExecutionState.build_for_reexecution(
+                    instance=instance,
+                    parent_run=check.not_none(instance.get_run_by_id(dagster_run.parent_run_id)),
+                )
             self.context = DagstermillRuntimeExecutionContext(
-                pipeline_context=pipeline_context,
-                pipeline_def=pipeline_def,
+                job_context=job_context,
+                job_def=job_def,
                 op_config=run_config.get("ops", {}).get(op.name, {}).get("config"),
                 resource_keys_to_init=get_required_resource_keys_to_init(
                     execution_plan,
-                    pipeline_def,
-                    resolved_run_config,
+                    job_def,
                 ),
                 op_name=op.name,
                 node_handle=node_handle,
                 step_context=cast(
-                    StepExecutionContext,
-                    pipeline_context.for_step(
-                        cast(ExecutionStep, execution_plan.get_step_by_key(step_key))
+                    "StepExecutionContext",
+                    job_context.for_step(
+                        cast("ExecutionStep", execution_plan.get_step_by_key(step_key)),
+                        known_state=known_state,
                     ),
                 ),
             )
@@ -204,7 +211,6 @@ class Manager:
         op_config: Any = None,
         resource_defs: Optional[Mapping[str, ResourceDefinition]] = None,
         logger_defs: Optional[Mapping[str, LoggerDefinition]] = None,
-        mode_def: Optional[ModeDefinition] = None,
         run_config: Optional[dict] = None,
     ) -> DagstermillExecutionContext:
         """Get a dagstermill execution context for interactive exploration and development.
@@ -220,31 +226,8 @@ class Manager:
         Returns:
             :py:class:`~dagstermill.DagstermillExecutionContext`
         """
-        check.opt_inst_param(mode_def, "mode_def", ModeDefinition)
         run_config = check.opt_dict_param(run_config, "run_config", key_type=str)
 
-        if resource_defs and mode_def:
-            raise DagsterInvariantViolationError(
-                "Attempted to provide both resource_defs and mode_def arguments to"
-                " `dagstermill.get_context`. Please provide one or the other."
-            )
-
-        if logger_defs and mode_def:
-            raise DagsterInvariantViolationError(
-                "Attempted to provide both logger_defs and mode_def arguments to"
-                " `dagstermill.get_context`. Please provide one or the other."
-            )
-
-        if mode_def:
-            deprecation_warning(
-                "mode_def argument to dagstermill.get_context",
-                "0.17.0",
-                (
-                    "Use the resource_defs argument to provide resources, and the logger_defs"
-                    " argument to provide loggers."
-                ),
-            )
-
         # If we are running non-interactively, and there is already a context reconstituted, return
         # that context rather than overwriting it.
         if self.context is not None and isinstance(
@@ -252,65 +235,61 @@ class Manager:
         ):
             return self.context
 
-        if not mode_def:
-            if not logger_defs:
-                logger_defs = {"dagstermill": colored_console_logger}
-                run_config["loggers"] = {"dagstermill": {}}
-            logger_defs = check.opt_mapping_param(logger_defs, "logger_defs")
-            resource_defs = check.opt_mapping_param(resource_defs, "resource_defs")
-            mode_def = ModeDefinition(logger_defs=logger_defs, resource_defs=resource_defs)
+        if not logger_defs:
+            logger_defs = {"dagstermill": colored_console_logger}
+            run_config["loggers"] = {"dagstermill": {}}
+        logger_defs = check.opt_mapping_param(logger_defs, "logger_defs")
+        resource_defs = check.opt_mapping_param(resource_defs, "resource_defs")
 
         op_def = OpDefinition(
             name="this_op",
             compute_fn=lambda *args, **kwargs: None,
             description="Ephemeral op constructed by dagstermill.get_context()",
-            required_resource_keys=mode_def.resource_key_set,
+            required_resource_keys=set(resource_defs.keys()),
         )
 
-        pipeline_def = PipelineDefinition(
-            [op_def], mode_defs=[mode_def], name="ephemeral_dagstermill_pipeline"
+        job_def = JobDefinition(
+            graph_def=GraphDefinition(name="ephemeral_dagstermill_pipeline", node_defs=[op_def]),
+            logger_defs=logger_defs,
+            resource_defs=resource_defs,
         )
 
         run_id = make_new_run_id()
 
-        # construct stubbed PipelineRun for notebook exploration...
-        # The actual pipeline run during pipeline execution will be serialized and reconstituted
-        # in the `reconstitute_pipeline_context` call
-        pipeline_run = DagsterRun(
-            pipeline_name=pipeline_def.name,
+        # construct stubbed DagsterRun for notebook exploration...
+        # The actual dagster run during job execution will be serialized and reconstituted
+        # in the `reconstitute_job_context` call
+        dagster_run = DagsterRun(
+            job_name=job_def.name,
             run_id=run_id,
             run_config=run_config,
-            mode=mode_def.name,
             step_keys_to_execute=None,
             status=DagsterRunStatus.NOT_STARTED,
             tags=None,
         )
 
-        self.in_pipeline = False
+        self.in_job = False
         self.op_def = op_def
-        self.pipeline = pipeline_def
+        self.job = job_def
 
-        resolved_run_config = ResolvedRunConfig.build(pipeline_def, run_config, mode=mode_def.name)
+        job = InMemoryJob(job_def)
+        execution_plan = create_execution_plan(job, run_config)
 
-        pipeline = InMemoryPipeline(pipeline_def)
-        execution_plan = ExecutionPlan.build(pipeline, resolved_run_config)
-
-        with scoped_pipeline_context(
+        with scoped_job_context(
             execution_plan,
-            pipeline,
+            job,
             run_config,
-            pipeline_run,
+            dagster_run,
             DagsterInstance.ephemeral(),
             scoped_resources_builder_cm=self._setup_resources,
-        ) as pipeline_context:
+        ) as job_context:
             self.context = DagstermillExecutionContext(
-                pipeline_context=pipeline_context,
-                pipeline_def=pipeline_def,
+                job_context=job_context,
+                job_def=job_def,
                 op_config=op_config,
                 resource_keys_to_init=get_required_resource_keys_to_init(
                     execution_plan,
-                    pipeline_def,
-                    resolved_run_config,
+                    job_def,
                 ),
                 op_name=op_def.name,
                 node_handle=NodeHandle(op_def.name, parent=None),
@@ -327,24 +306,24 @@ class Manager:
             value (Any): The value to yield.
             output_name (Optional[str]): The name of the result to yield (default: ``'result'``).
         """
-        if not self.in_pipeline:
+        if not self.in_job:
             return value
 
         # deferred import for perf
         import scrapbook
 
-        if not self.op_def.has_output(output_name):
+        if not self.op_def.has_output(output_name):  # pyright: ignore[reportOptionalMemberAccess]
             raise DagstermillError(
-                f"Op {self.op_def.name} does not have output named {output_name}.Expected one of"
-                f" {[str(output_def.name) for output_def in self.op_def.output_defs]}"
+                f"Op {self.op_def.name} does not have output named {output_name}.Expected one of"  # pyright: ignore[reportOptionalMemberAccess]
+                f" {[str(output_def.name) for output_def in self.op_def.output_defs]}"  # pyright: ignore[reportOptionalMemberAccess]
             )
 
         # pass output value cross process boundary using io manager
-        step_context = self.context._step_context  # noqa: SLF001
+        step_context = self.context._step_context  # noqa: SLF001  # pyright: ignore[reportAttributeAccessIssue,reportOptionalMemberAccess]
         # Note: yield_result currently does not support DynamicOutput
 
         # dagstermill assets do not support yielding additional results within the notebook:
-        if len(step_context.job_def.asset_layer.asset_keys) > 0:
+        if len(step_context.job_def.asset_layer.executable_asset_keys) > 0:  # pyright: ignore[reportArgumentType]
             raise DagstermillError(
                 "dagstermill assets do not currently support dagstermill.yield_result"
             )
@@ -384,14 +363,14 @@ class Manager:
                 f" type, one of {valid_types}."
             )
 
-        if not self.in_pipeline:
+        if not self.in_job:
             return dagster_event
 
         # deferred import for perf
         import scrapbook
 
-        event_id = f"event-{str(uuid.uuid4())}"
-        out_file_path = os.path.join(self.marshal_dir, event_id)
+        event_id = f"event-{uuid.uuid4()}"
+        out_file_path = os.path.join(self.marshal_dir, event_id)  # pyright: ignore[reportCallIssue,reportArgumentType]
         with open(out_file_path, "wb") as fd:
             fd.write(pickle.dumps(dagster_event, PICKLE_PROTOCOL))
 
