@@ -1,11 +1,11 @@
-from dagster import _seven
+from dagster_shared import seven
 
 PICKLE_PROTOCOL = 2
 
 
 def is_json_serializable(value):
     try:
-        _seven.json.dumps(value)
+        seven.json.dumps(value)
         return True
     except TypeError:
         return False
