@@ -1,6 +1,6 @@
 import papermill
 import papermill.translators
-from dagster import _seven
+from dagster_shared import seven
 
 RESERVED_INPUT_NAMES = [
     "__dm_context",
@@ -16,13 +16,13 @@ RESERVED_INPUT_NAMES = [
 
 INJECTED_BOILERPLATE = """
 # Injected parameters
-from dagster import seven as __dm_seven
+from dagster_shared import seven as __dm_seven
 import dagstermill as __dm_dagstermill
-context = __dm_dagstermill._reconstitute_pipeline_context(
+context = __dm_dagstermill._reconstitute_job_context(
     **{{
         key: __dm_seven.json.loads(value)
         for key, value
-        in {pipeline_context_args}.items()
+        in {job_context_args}.items()
     }}
 )
 """
@@ -41,19 +41,19 @@ class DagsterTranslator(papermill.translators.PythonTranslator):
         assert "__dm_input_names" in parameters
 
         context_args = parameters["__dm_context"]
-        pipeline_context_args = dict(
+        job_context_args = dict(
             executable_dict=parameters["__dm_executable_dict"],
-            pipeline_run_dict=parameters["__dm_pipeline_run_dict"],
+            job_run_dict=parameters["__dm_pipeline_run_dict"],
             node_handle_kwargs=parameters["__dm_node_handle_kwargs"],
             instance_ref_dict=parameters["__dm_instance_ref_dict"],
             step_key=parameters["__dm_step_key"],
             **context_args,
         )
 
-        for key in pipeline_context_args:
-            pipeline_context_args[key] = _seven.json.dumps(pipeline_context_args[key])
+        for key in job_context_args:
+            job_context_args[key] = seven.json.dumps(job_context_args[key])
 
-        content = INJECTED_BOILERPLATE.format(pipeline_context_args=pipeline_context_args)
+        content = INJECTED_BOILERPLATE.format(job_context_args=job_context_args)
 
         for input_name in parameters["__dm_input_names"]:
             dm_load_input_call = f"__dm_dagstermill._load_input_parameter('{input_name}')"
